ACWS Control Panel

# 🏁 ACWS Control Panel

Version
Disconnected

## Server Control

Game
n/a
Config
n/a
name:
n/a
track:
n/a
cars:
n/a
practice:
qualify:
race:

## Drivers

Name | Car
--- | ---
No drivers connected

## Grid Management

ini:
entry_list.ini
order by:

Position | Name | GUID | Car | Ballast | Restrictor | Connected
--- | --- | --- | --- | --- | --- | ---

## Lobby

registered:
n/a
No lobby information available

## stracker

started:
n/a
No tracker information available

## Message Log

### Configuration Error